@@ -5,7 +5,7 @@ use 5.006;
 use strict;
 
 our $NAME       = __PACKAGE__;     # name of entire application
-our $VERSION    = '0.3.10.23';           # version of entire app
+our $VERSION    = '0.3.10.24';           # version of entire app
 our $PATCHLEVEL = 0;               # has just stable versions
 our $STANDALONE = '';              # starter flag for moveable installations
 our $BENCHMARK;                    # flag for benchmark loggings
@@ -110,7 +110,8 @@ sub configdir {
 
 # Wx App Events
 sub OnInit { &Kephra::App::start }   # boot app: init core and load config files
-sub quit   { &Kephra::App::exit  }   # save files & settings as configured
+sub quit   { &Kephra::App::exit  
+}   # save files & settings as configured
 
 1;
 
